@@ -2,7 +2,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 //
-// Copyright (c) 2009-2013 Icinga Developer Team.
+// Copyright (c) 2009-present Icinga Developer Team.
 // All rights reserved.
 //
 // icinga-web is free software: you can redistribute it and/or modify
@@ -38,8 +38,6 @@ Ext.ns('Icinga.Cronks.System');
 
         this.categories = {};
 
-        this.default_act = -1;
-
         var fillStore = function (storeid, data) {
 
             if (Ext.isEmpty(CLP.stores[storeid])) {
@@ -113,7 +111,7 @@ Ext.ns('Icinga.Cronks.System');
             });
         };
 
-        var createView = function (storeid, title) {
+        var createView = function (storeid, title, collapsed) {
 
             var store = CLP.getStore(storeid);
 
@@ -161,7 +159,9 @@ Ext.ns('Icinga.Cronks.System');
 
             CLP.add({
                 title: String.format('{0} ({1})', title, store.getCount()),
+                collapsed: collapsed ? true : false,
                 autoScroll: false,
+                catid: storeid,
 
                 /*
                  * Bubbeling does not work because it collapse the
@@ -170,6 +170,9 @@ Ext.ns('Icinga.Cronks.System');
                 listeners: {
                     collapse: function (panel) {
                         CLP.saveState();
+                    },
+                    expand: function (panel) {
+                        CLP.saveState();
                     }
                 },
 
@@ -194,7 +197,7 @@ Ext.ns('Icinga.Cronks.System');
 
         };
 
-        this.loadData = function (url, act) {
+        this.loadData = function (url) {
 
             var mask = null;
 
@@ -229,12 +232,22 @@ Ext.ns('Icinga.Cronks.System');
                                     fillStore(item.catid, data.cronks[item.catid]);
                                 } else {
                                     fillStore(item.catid, data.cronks[item.catid]);
-                                    createView(item.catid, item.title);
 
-                                    if (Ext.isDefined(item.active) && item.active === true) {
-                                        this.default_act = i;
+                                    var collapsed = false;
+
+                                    // if something in state, calculate based on state
+                                    if (!Ext.isEmpty(this.collapsed_categories)) {
+                                        Ext.each(this.collapsed_categories, function(catid, index, l) {
+                                            if (catid === item.catid) collapsed = true;
+                                        }, this);
+                                    }
+                                    // or use default settings from xml
+                                    else if(Ext.isDefined(item.collapsed) && item.collapsed === true) {
+                                        collapsed = true;
                                     }
 
+                                    // actually create the item
+                                    createView(item.catid, item.title, collapsed);
                                 }
 
                                 i++;
@@ -242,11 +255,7 @@ Ext.ns('Icinga.Cronks.System');
                             }
                         }, this);
 
-                        AppKit.util.Layout.doLayout(null, 200);
-                        // this.doLayout();
-                        if (!Ext.isEmpty(act)) {
-                            this.getLayout().setActiveItem(act);
-                        }
+                        this.doLayout();
                     }
                 },
                 failure: function (r, o) {
@@ -262,30 +271,19 @@ Ext.ns('Icinga.Cronks.System');
 
         };
 
-        this.loadData(this.combinedProviderUrl);
-
-        CLP.on('afterrender', function () {
-            if (!CLP.applyActiveItem() && this.default_act >= 0) {
-                CLP.setActiveItem(this.default_act);
-            }
-        });
-
         var cb = Cronk.util.CronkBuilder.getInstance();
 
         cb.addListener('writeSuccess', function () {
             CLP.reloadAll();
         });
+
+        // loading the cronk data after component has been rendered
+        this.on("render", function() {
+            this.loadData(this.combinedProviderUrl);
+        }, this);
     };
 
     Ext.extend(Icinga.Cronks.System.CronkListingPanel, Ext.Panel, {
-        layout: 'accordion',
-        layoutConfig: {
-            animate: true,
-            renderHidden: false,
-            hideCollapseTool: true,
-            fill: false
-        },
-
         customCronkCredential: false,
         isCronkAdmin: false,
         isCategoryAdmin: false,
@@ -294,7 +292,9 @@ Ext.ns('Icinga.Cronks.System');
         border: false,
 
         defaults: {
-            border: false
+            border: true,
+            collapsible: true,
+            titleCollapse: true
         },
 
         bodyCfg: {
@@ -303,7 +303,7 @@ Ext.ns('Icinga.Cronks.System');
 
         stateful: true,
 
-        stateEvents: ['collapse'],
+        stateEvents: ['startTabSlider', 'stopTabSlider'],
         bubbleEvents: [],
 
         tbar: [{
@@ -342,72 +342,53 @@ Ext.ns('Icinga.Cronks.System');
             }, {
                 text: _("Tab slider"),
                 checked: false,
+                id: 'tabslider',
+                itemId: 'tabslider',
                 checkHandler: function (checkItem, checked) {
-
-                    var refresh = AppKit.getPrefVal('org.icinga.tabslider.changeTime') || 60;
-
-                    var tp = Ext.getCmp('cronk-tabs');
-
                     if (checked === true) {
-                        if (Ext.isDefined(this.sliderTask)) {
-                            AppKit.getTr().stop(this.sliderTask);
-                        }
-
-                        this.sliding_tab = tp.getActiveTabIndex();
-
-                        this.sliderTask = {
-                            run: function () {
-                                this.sliding_tab++;
-                                if (this.sliding_tab >= tp.items.getCount()) {
-                                    this.sliding_tab = 0;
-                                }
-
-                                tp.setActiveTab(this.sliding_tab);
-                            },
-                            interval: (refresh * 1000),
-                            scope: this
-                        };
-
-                        AppKit.getTr().start(this.sliderTask);
+                        Ext.getCmp('cronk-listing-panel').startTabSlider();
                     } else {
-                        AppKit.getTr().stop(this.sliderTask);
+                        Ext.getCmp('cronk-listing-panel').stopTabSlider();
                     }
-
-                },
-                scope: this
-            }
-            ]
+                }
+            }]
         }
         ],
 
         initComponent: function () {
             Icinga.Cronks.System.CronkListingPanel.superclass.initComponent.call(this);
+
+            this.addEvents({
+                startTabSlider: true,
+                stopTabSlider: true
+            });
         },
 
         applyState: function (state) {
-            if (!Ext.isEmpty(state.active_tab) && state.active_tab >= 0) {
-                this.active_tab = state.active_tab;
+            if (!Ext.isEmpty(state.collapsed_categories)) {
+                this.collapsed_categories = state.collapsed_categories;
             }
             if (!Ext.isEmpty(state.cronkliststyle)) {
                 this.applyCronkStyle(state.cronkliststyle, false);
             }
+            if (Ext.isDefined(state.tabslider_active) && state.tabslider_active === true) {
+                this.startTabSlider();
+                Ext.getCmp('tabslider').setChecked(true);
+            }
         },
 
         getState: function () {
-            var active = this.getLayout().activeItem,
-                i;
+            this.collapsed_categories = [];
             this.items.each(function (item, index, l) {
-                if (item === active) {
-                    i = index;
+                if (item.catid && item.collapsed && item.collapsed === true) {
+                    this.collapsed_categories.push(item.catid);
                 }
-            });
+            }, this);
 
-            if (typeof (i) === "undefined" || i < 0) {
-                i = 0;
-            }
             return {
-                active_tab: i,
-                cronkliststyle: this.cronkliststyle ? this.cronkliststyle : null
+                collapsed_categories: this.collapsed_categories,
+                cronkliststyle: this.cronkliststyle ? this.cronkliststyle : null,
+                tabslider_active: Ext.isDefined(this.sliderTask) ? true : false
             };
         },
 
@@ -438,13 +419,14 @@ Ext.ns('Icinga.Cronks.System');
                 // menu
                 Ext.getCmp('cronkliststyle-menu-list').setChecked(true, true);
             }
-            west.fireEvent("expand");
+            // force layout re-render to avoid glitching
+            AppKit.util.Layout.doLayout(null, 10);
+
             view.saveState();
             west.saveState();
 
             // Reload the data if required
             if (reload) {
-                this.saveState();
                 this.reloadAll();
             }
         },
@@ -551,19 +533,6 @@ Ext.ns('Icinga.Cronks.System');
             });
         },
 
-        setActiveItem: function (id) {
-            this.getLayout().setActiveItem(id);
-        },
-
-        applyActiveItem: function () {
-            var c = this;
-            if (!Ext.isEmpty(c.active_tab)) {
-                c.getLayout().setActiveItem(c.active_tab);
-                return true;
-            }
-            return false;
-        },
-
         getContextmenu: function () {
 
             var idPrefix = this.id + '-context-menu';
@@ -730,17 +699,6 @@ Ext.ns('Icinga.Cronks.System');
         },
 
         reloadAll: function () {
-
-            var act = 0,
-                i = 0;
-            this.items.each(function (item) {
-                if (this.getLayout().activeItem === item) {
-                    act = i;
-                    return false;
-                }
-                i++;
-            }, this);
-
             this.removeAll();
 
             Ext.iterate(this.stores, function (storeid, store) {
@@ -748,8 +706,52 @@ Ext.ns('Icinga.Cronks.System');
                 delete(this.stores[storeid]);
             }, this);
 
-            this.loadData(this.combinedProviderUrl, act);
+            this.loadData(this.combinedProviderUrl);
+        },
+
+        /**
+         * Start a task to iterate active tabs
+         */
+        startTabSlider: function() {
+
+            if (Ext.isDefined(this.sliderTask)) {
+                return;
+            }
+
+            var refresh = AppKit.getPrefVal('org.icinga.tabslider.changeTime') || 60;
+
+            var tp = Ext.getCmp('cronk-tabs');
+
+            this.sliding_tab = tp.getActiveTabIndex();
+
+            this.sliderTask = {
+                run: function () {
+                    this.sliding_tab++;
+                    if (this.sliding_tab >= tp.items.getCount()) {
+                        this.sliding_tab = 0;
+                    }
+
+                    tp.setActiveTab(this.sliding_tab);
+                },
+                interval: (refresh * 1000),
+                scope: this
+            };
+
+            AppKit.getTr().start(this.sliderTask);
+
+            this.fireEvent('startTabSlider');
+        },
+
+        /**
+         * Stop the tasks which iterate tabs
+         */
+        stopTabSlider: function() {
+            if (Ext.isDefined(this.sliderTask)) {
+                AppKit.getTr().stop(this.sliderTask);
+                delete(this.sliderTask);
+                this.fireEvent('stopTabSlider');
+            }
         }
     });
 
-})();
\ No newline at end of file
+})();
